<?php
/*
a(tom)Blog is a atom powered weblog system.
Copyright (C) 2004  Yoan BLANC

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/// file_put_contents for <PHP5
if (!function_exists('file_put_contents')) {
   define('FILE_APPEND', 1);
   function file_put_contents($filename, $content, $flags = 0) {
       if (!($file = fopen($filename, ($flags & FILE_APPEND) ? 'a' : 'w')))
           return false;
       $n = fwrite($file, $content);
       fclose($file);
       return $n ? $n : false;
   }
}

/// file_get_contents for <PHP5
if (!function_exists('file_get_contents'))
{
    function file_get_contents($filename, $use_include_path = 0)
    {
        $file = @fopen($filename, 'ab', $use_include_path);
        if ($file)
        {
            if ($fsize = @filesize($filename))
            {
                $data = fread($file, $fsize);
            }
            else
            {
                while (!feof($file))
                {
                    $data .= fread($file, 1024);
                }
            }
            fclose($file);
        }
        return $data;
    }
} 

/// str_split for <PHP5
if (!function_exists('str_split')) {
  function str_split($string, $chunksize=1) {
   preg_match_all('/('.str_repeat('.', $chunksize).')/Uims', $string, $matches);
   return $matches[1];
  }
}

/**
 * Capture info from the headers
 *
 * @return info array
 */
function captureInfo()
{
	$info = array();
	
	if(isset($_SERVER['REQUEST_METHOD']))
		$info['method'] = $_SERVER['REQUEST_METHOD'];
	if(isset($_SERVER['CONTENT_TYPE']))
		$info['type'] = $_SERVER['CONTENT_TYPE'];
	
	if(isset($_SERVER['CONTENT_LENGTH']))
		$info['length'] = $_SERVER['CONTENT_LENGTH'];
	
	if(isset($_SERVER['USER_AGENT']))
		$info['agent'] = $_SERVER['USER_AGENT'];

	if(isset($_SERVER['REQUEST_URI']))
		$info['url'] = $_SERVER['REQUEST_URI'];
	
	if(isset($_SERVER['HTTP_X_ATOM_AUTHENTICATION']))
	{
		$info['x-atom-authentication']['all'] = stripslashes($_SERVER['HTTP_X_ATOM_AUTHENTICATION']);
		$tmp = explode('", ',$info['x-atom-authentication']['all']);
		foreach($tmp as $elem)
		{
			$tinytmp = explode('="',$elem);
			$val = str_replace('"','',$tinytmp[1]);
			
			switch(trim($tinytmp[0]))
			{
				case "Atom username":
					$info['x-atom-authentication']['user'] = $val;
					break;
				case "realm":
					$info['x-atom-authentication']['realm'] = $val;
					break;
				case "nonce":
					$info['x-atom-authentication']['nonce'] = $val;
					break;
				case "cnonce":
					$info['x-atom-authentication']['cnonce'] = $val;
					break;
				case "uri":
					$info['x-atom-authentication']['uri'] = $val;
					break;
				case "qop":
					$info['x-atom-authentication']['qop'] = $val;
					break;
				case "nc":
					$info['x-atom-authentication']['nc'] = $val;
					break;
				case "response":
					$info['x-atom-authentication']['response'] = $val;
					break;
			}
		}
	}
	
	if(isset($info['method']) && (strtoupper($info['method']) == 'PUT' || strtoupper($info['method']) == 'POST'))
	{
		$info['data'] = implode(file("php://input"),'');
	}
	
	return $info;
}

/**
 * Capture informations from the request uri (cool uri mode)
 *
 * @return info
 */
function captureGet()
{
	$out['request'] = $_SERVER['REQUEST_URI'];
	
	$data = (explode("/",$out['request']));
	//$out['data'] = $data;
	
	$out['mode'] = 'help';
	
	if(isset($data[2]) && !empty($data[2]))
	{
		$out['login'] = $data[2];
		$out['mode'] = 'user';
		
		if(isset($data[3]) && !empty($data[3]) && file_exists('atomServer/data/'.$out['login']))
		{
			$out['method'] = $data[3];
			if((int)$out['method'] >= 1970 && (int)$out['method'] <= 2070)
			{
				$out['mode'] = 'year';
				$out['date'] = (int)$out['method'];
				// month
				if(isset($data[4]) && !empty($data[4]) &&
					strlen($data[4]) == 2 &&
					(int)$data[4] > 0 && (int)$data[4] <= 12)
				{
					$out['mode'] = 'month';
					$out['date'] .= '/'.$data[4];
					// day
					if(isset($data[5]) && !empty($data[5]) &&
						strlen($data[5]) == 2 &&
						(int)$data[5] > 0 && (int)$data[5] <= 31)
					{
						$out['mode'] = 'day';
						$out['date'] .= '/'.$data[5];
						if(isset($data[6]) && !empty($data[6]))
						{
							$out['mode'] = 'entry';
							$out['entry'] = $data[6];
							if(ereg('.xml$',$data[6]))
							{
								$out['method'] = 'atom';
							}
							elseif(ereg('.html$',$data[6]))
							{
								$out['entry'] = ereg_replace('.html','.xml',$out['entry']);
								$out['method'] = 'html';
							}
							elseif(strlen($data[6]) == 6)
							{
								$out['entry'] .= '.xml';
								$out['method'] = 'html';
							}
							else
							{
								redirect('/'.$data[1].'/'.$data[2].'/'.$data[3].'/'.$data[4].'/'.$data[5]);
							}
						}
						elseif(!isset($data[6]))
						{
							redirect($out['request'].'/');
						}
					}
					else if(isset($data[5]) && !empty($data[5]))
					{
						redirect('/'.$data[1].'/'.$data[2].'/'.$data[3].'/'.$data[4].'/');
					}
					elseif(!isset($data[5]))
					{
						redirect($out['request'].'/');
					}
					
				}
				else if(isset($data[4]) && !empty($data[4]))
				{
					redirect('/'.$data[1].'/'.$data[2].'/'.$data[3].'/');
				}
				else if(!isset($data[4]))
				{
					redirect($out['request'].'/');
				}
			}
			else if(substr($out['method'],-4,4) == '.xml')
			{
				$out['mode'] = 'feed';
				switch($out['method'])
				{
					case 'atom.xml':
						$out['method']='atom';
						break;
					case 'rss091.xml':
						$out['method']='rss091';
						break;
					case 'introspection.xml':
						$out['mode']='introspection';
						break;
					default:
						unset($out['mode']);
						unset($out['method']);
				}
			}
			elseif(isset($data[3]) && !empty($data[3]))
			{
				redirect('/'.$data[1].'/'.$data[2].'/');
			}
		}
		else if(!isset($data[3]))
		{
			redirect($out['request'].'/');
		}
		else if(!file_exists('atomServer/data/'.$out['login']))
		{
			$out = '<error><msg>no user</msg></error>';
		}
	}
	else
	{
		redirect('/');
	}
	
	return $out;
}

/**
 * HTTP redirection
 *
 * @param $url new relative url
 */
function redirect($url)
{
	$urlroot = 'http://atom.dosimple.ch';
	//echo "<p><strong>Redirection :</strong> <tt>".$url."</tt></p>";
	header("Moved Permanently", TRUE, 301);
	header("Location : ".$urlroot.$url);
	header("Connection: close");//*/
}

/**
 * format an email address
 *
 * @param $mail email address
 * @return email encoding
 */
function emailformat($mail)
{
	return '<a href="mailto:'.hex_encode($mail).'">'.str_replace('@',' [at] ',$mail).'</a>';
}

/**
 * Hexadecimal encoding
 *
 * @see http://www.neokraft.net/sottises/mailencoder/
 * @author Olivier Meunier
 */
function hex_encode ($str)
{
	$encoded = bin2hex($str); 
	$encoded = chunk_split($encoded, 2, '%'); 
	$encoded = '%'.substr($encoded, 0, strlen($encoded) - 1); 
	return $encoded; 
}

/**
 * Protect email from spammers
 *
 * @param $str element from a preg_match
 * @return clean url
 */
function antiSpam($str)
{
	return 'href="mailto:'.hex_encode($str[1]).'"'; 
}

/**
 * Delete recusivly a folder
 * same as : rm -rf *
 *
 * @param $dir folder
 * @param return true if success
 * @see http://ch.php.net/manual/fr/function.rmdir.php
 */
function deldir($dir)
{
  $handle = opendir($dir);
  while (false!==($FolderOrFile = readdir($handle)))
  {
     if($FolderOrFile != "." && $FolderOrFile != "..")
     { 
       if(is_dir("$dir/$FolderOrFile"))
       { deldir("$dir/$FolderOrFile"); }  // recursive
       else
       { unlink("$dir/$FolderOrFile"); }
     } 
  }
  closedir($handle);
  if(rmdir($dir))
  { $success = true; }
  return $success; 
}

/**
 * My htmlentities, title and summary needs (to be edited with admin area)
 *
 * @param $txt
 * @return formatted string
 */
function htmlent($txt)
{
	//return htmlentities($txt,ENT_QUOTES,'UTF-8');
	
	//	\s     any whitespace character
    //	\S     any character that is not a whitespace character
	//	\w	any word character
	//``
	$txt = preg_replace("/(\W)\"(\w)/si",'\1“\2',$txt);
	//''
	$txt = preg_replace("/(\S)\"(\s)/si",'\1”\2',$txt);
	//`
	$txt = preg_replace("/(\s)'(\S)/si",'\1‘\2',$txt);
	//'
	$txt = preg_replace("/(\S)'(\s)/si",'\1’\2',$txt);
	$txt = preg_replace("/(\S)'(\S)/si",'\1’\2',$txt);
	// et le reste.
	$txt = str_replace("'","’",$txt);
	$txt = str_replace('"',"”",$txt);
	return $txt;
}
?>