<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
  version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml">
<!--
	XHTML lib
	=========
	
	A collection of "tools" to generate the xhtml version.
	
	meta-data
	=========
	
	- author Yoan BLANC
	- licence GPL
	- version 0.1 040625
-->

<!--
	build the head of the page (without meta information just "clean")
-->
<xsl:template name="head">
	<xsl:param name="title" />
	
	<title><xsl:value-of select="$title" /></title>
	<!-- in this version it isn't possible to change the stylesheet -->
	<link rel="stylesheet" type="text/css" title="yellow_bw" href="/templates/yellow_bw.css"/>
</xsl:template>

<xsl:template name="header_info">
	<!-- user login -->
	<xsl:param name="login" />
	<!-- user element (see users.xml) -->
	<xsl:param name="user" />
	<!-- the language -->
	<xsl:param name="lang" select="en" />
	
	<!-- title is the user name -->
	<div id="header_info">
		<h1><xsl:value-of select="$user/name" /></h1>
	</div>
	
	<!-- the top menu with user homepage, mail, atom feed and rss0.91 feed -->
	<ul id="menu">
		<li><a>
		<xsl:attribute name="href">
			<xsl:text>/atom/</xsl:text>
			<xsl:value-of select="$login" />
			<xsl:text>/</xsl:text>
		</xsl:attribute>
		<xsl:value-of select="document('text.xml')/texts/text[lang($lang)]/homepage"/></a></li>
		<li><a>
		<xsl:attribute name="href">
			<xsl:value-of select="concat('mailto:',$user/email)" />
		</xsl:attribute>
		<xsl:value-of select="document('text.xml')/texts/text[lang($lang)]/mail"/></a></li>
		<li>
			<a title="atom">
				<xsl:attribute name="href">
					<xsl:text>/atom/</xsl:text>
					<xsl:value-of select="$login" />
					<xsl:text>/atom.xml</xsl:text>
				</xsl:attribute>
				xml
			</a>
		</li>
		<li><a title="rss 0.91">
			<xsl:attribute name="href">
				<xsl:text>/atom/</xsl:text>
				<xsl:value-of select="$login" />
				<xsl:text>/rss091.xml</xsl:text>
			</xsl:attribute>
		<abbr title="Rich Site Summary">RSS</abbr></a></li>
	</ul>
</xsl:template>

<!--
	Build the services link tags
	
	- service.post
	- service.feed
	
	and the alternate who's pointing on rss feed.
-->
<xsl:template name="services">
	<!-- user login -->
	<xsl:param name="login" />

	<link rel="service.post" type="application/x.atom+xml">
		<xsl:attribute name="href">
			<xsl:text>/atom/</xsl:text>
			<xsl:value-of select="$login" />
			<xsl:text>/</xsl:text>
		</xsl:attribute>
	</link>
	<link rel="service.feed" type="application/x.atom+xml" title="atom">
		<xsl:attribute name="href">
			<xsl:text>/atom/</xsl:text>
			<xsl:value-of select="$login" />
			<xsl:text>/atom.xml</xsl:text>
		</xsl:attribute>
	</link>
	<link rel="alternate" type="application/rss+xml" title="rss 0.91">
		<xsl:attribute name="href">
			<xsl:text>/atom/</xsl:text>
			<xsl:value-of select="$login" />
			<xsl:text>/rss091.xml</xsl:text>
		</xsl:attribute>
	</link>
</xsl:template>

<!--
	the months list
-->
<xsl:template name="archives">
	<!-- the feed -->
	<xsl:param name="feed" />
	<!-- user login -->
	<xsl:param name="login" />
	<!-- the language -->
	<xsl:param name="lang" select="en" />

	<h4><xsl:value-of select="document('text.xml')/texts/text[lang($lang)]/archives"/></h4>
	<ul>
	<xsl:for-each select="$feed/entry">
		<xsl:if test="not(substring(preceding-sibling::entry/@id,0,8) = substring(@id,0,8))">
			<li><a>
				<xsl:attribute name="href">
					<xsl:text>/atom/</xsl:text>
					<xsl:value-of select="$login" />
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring(@id,0,8)"/>
					<xsl:text>/</xsl:text>
				</xsl:attribute>
				<xsl:call-template name="formatDateArchive">
					<xsl:with-param name="date" select="substring(@id,0,8)"/>
					<xsl:with-param name="lang" select="$lang"/>
				</xsl:call-template>
			</a></li>
		</xsl:if>
	</xsl:for-each>
	</ul>
</xsl:template>

<!--
	the full xhtml version displaying the content.
-->
<xsl:template name="xhtml-fullentry">
	<!-- entry's id -->
	<xsl:param name="id" />
	<!-- entry -->
	<xsl:param name="entry" />

	<div class="entry">
		<h2><xsl:value-of select="$entry/title" /></h2>
		<p class="entry_info">
			<a>
				<xsl:attribute name="href">
					<xsl:text>/atom/</xsl:text>
					<xsl:value-of select="$login" />
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before($id,'_')"/>
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before(substring-after($id,'_'),'.')"/>
					<xsl:text>.html</xsl:text>
				</xsl:attribute>
			<xsl:call-template name="formatFullDate">
				<xsl:with-param name="date" select="$entry/issued"/>
				<xsl:with-param name="lang" select="document('../../data/users.xml')//users/user[@login = $login]/@xml:lang"/>
			</xsl:call-template>
			</a>
		</p>
		<xsl:copy-of select="$entry/content/*" />
	</div>
</xsl:template>

<!--
	the small xhtml version displaying the summary only.
-->
<xsl:template name="xhtml-smallentry">
	<!-- entry's id -->
	<xsl:param name="id" />
	<!-- entry -->
	<xsl:param name="entry" />
	<!-- language -->
	<xsl:variable name="lang" select="document('../../data/users.xml')//users/user[@login = $login]/@xml:lang"/>

	<div class="entry">
		<h2><xsl:value-of select="$entry/title" /></h2>
		<p class="entry_info">
			<a>
				<xsl:attribute name="href">
					<xsl:text>/atom/</xsl:text>
					<xsl:value-of select="$login" />
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before($id,'_')"/>
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before(substring-after($id,'_'),'.')"/>
					<xsl:text>.html</xsl:text>
				</xsl:attribute>
			<xsl:call-template name="formatFullDate">
				<xsl:with-param name="date" select="$entry/issued"/>
				<xsl:with-param name="lang" select="$lang"/>
			</xsl:call-template>
			</a>
		</p>
		<p class="summary">
			<xsl:value-of select="$entry/summary" />
		</p>
		<p class="more">
			<a>
				<xsl:attribute name="href">
					<xsl:text>/atom/</xsl:text>
					<xsl:value-of select="$login" />
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before($id,'_')"/>
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring-before(substring-after($id,'_'),'.')"/>
					<xsl:text>.html</xsl:text>
				</xsl:attribute>
				<xsl:value-of select="document('text.xml')/texts/text[lang($lang)]/more"/>
			</a>
		</p>
	</div>
</xsl:template>

<!--
	the entry link
-->
<xsl:template name="archive">
	<!-- entry's id -->
	<xsl:param name="id"/>
	<!-- user login -->
	<xsl:param name="login"/>
	<!-- entry -->
	<xsl:param name="entry"/>
	
	<a>
		<xsl:attribute name="href">
			<xsl:text>/atom/</xsl:text>
			<xsl:value-of select="$login" />
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring-before($id,'_')"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring-before(substring-after($id,'_'),'.')"/>
			<xsl:text>.html</xsl:text>
		</xsl:attribute>
		<xsl:value-of select="$entry/title" />
	</a>
</xsl:template>

</xsl:stylesheet>