<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet
  version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml">
<!--
	XHTML archives
	==============
	
	Display the archives for a day, month or year
	
	meta-data
	=========
	
	- author Yoan BLANC
	- licence GPL
	- version 0.1 040625
-->
<xsl:import href="templates/date.xsl" />
<xsl:import href="templates/xhtml.xsl" />

<xsl:output
	method="xml"
	encoding="utf-8"
	indent="yes"
	omit-xml-declaration="no"
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"/>

<!-- user's login -->
<xsl:param name="login" />
<!-- date {YYYY}, {YYYY/MM} or {YYYY/MM/DD} -->
<xsl:param name="archive" />

<xsl:template match="/">
	<html>
	<xsl:attribute name="xml:lang">
		<xsl:value-of select="//user[@login = $login]/@xml:lang"/>
	</xsl:attribute>
	<head>
		<xsl:call-template name="head">
			<xsl:with-param name="title" select="$archive" />
		</xsl:call-template>
		<xsl:call-template name="services">
			<xsl:with-param name="login" select="$login" />
		</xsl:call-template>
	</head>
	<body>
		<div id="header">
			<xsl:call-template name="header_info">
				<xsl:with-param name="login" select="$login"/>
				<xsl:with-param name="user" select="//user[@login = $login]"/>
				<xsl:with-param name="lang" select="//user[@login = $login]/@xml:lang"/>
			</xsl:call-template>
		</div>
		<div id="page">
			<xsl:apply-templates select="document(concat('../data/',$login,'/feed.xml'))/feed" mode="archive_feed" />
		</div>
		<div id="archives">
			<xsl:call-template name="archives">
				<xsl:with-param name="login" select="$login"/>
				<xsl:with-param name="feed" select="document(concat('../data/',$login,'/feed.xml'))/*"/>
				<xsl:with-param name="lang" select="//users/user[@login = $login]/@xml:lang"/>
			</xsl:call-template>
		</div>
		<div id="footer">
			<p><a href="/">a(tom)Blog</a> | by Yoan BLANC</p>
		</div>
	</body>
	</html>
</xsl:template>

<!--
	Build the content element
-->
<xsl:template match="feed" mode="archive_feed">
	<div class="entry">
		<h2><xsl:value-of select="$archive"/></h2>
		
		<ul>
			<xsl:apply-templates select="//entry[starts-with(@id, $archive)]" mode="archive_entry" />
		</ul>
	</div>
</xsl:template>

<!--
	Build the list of entries
-->
<xsl:template match="entry" mode="archive_entry">
	<li>
		<xsl:call-template name="archive">
			<xsl:with-param name="id" select="@id" />
			<xsl:with-param name="login" select="$login" />
			<xsl:with-param name="entry" select="document(concat('../data/',$login,'/',@id))/entry" />
		</xsl:call-template>
	</li>
</xsl:template>

</xsl:stylesheet>